summaryrefslogtreecommitdiff
path: root/include/ec_commands.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ec_commands.h')
-rw-r--r--include/ec_commands.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/ec_commands.h b/include/ec_commands.h
index 67d026118f..d15c213e98 100644
--- a/include/ec_commands.h
+++ b/include/ec_commands.h
@@ -4179,7 +4179,8 @@ enum ec_pd_control_cmd {
PD_SUSPEND = 0, /* Suspend the PD chip (EC: stop talking to PD) */
PD_RESUME, /* Resume the PD chip (EC: start talking to PD) */
PD_RESET, /* Force reset the PD chip */
- PD_CONTROL_DISABLE /* Disable further calls to this command */
+ PD_CONTROL_DISABLE, /* Disable further calls to this command */
+ PD_CHIP_ON, /* Power on the PD chip */
};
struct __ec_align1 ec_params_pd_control {